======
STPIPE
======

.. _stpipe-user-steps:

For Users
=========
.. toctree::
   :maxdepth: 2

   user_step.rst
   user_pipeline.rst
   user_logging.rst
   config_asdf.rst
   call_via_call.rst
   call_via_run.rst
   parameter_files.rst


.. _stpipe-devel-steps:

For Developers
==============
.. toctree::
   :maxdepth: 2

   devel_step.rst
   devel_pipeline.rst
   devel_logging.rst

.. automodapi:: romancal.stpipe
